import {__rest}from'tslib';import*as React from'react';import {extendTheme,ChakraProvider,Box,Divider}from'@chakra-ui/react';import {HashRouter,Switch,Route,Redirect,useLocation}from'react-router-dom';import HomePage from'./Pages/HomePage.js';import SingleRoom from'./Pages/SingleRoom.js';import ErrorPage from'./Pages/ErrorPage.js';import RoomsPage from'./Pages/RoomsPage.js';import Footer from'./components/NavComponents/Footer.js';import {QueryClient,QueryClientProvider}from'react-query';import {AuthProvider,AuthContext}from'./Contexts/AuthContext.js';import ProfilePage from'./Pages/ProfilePage.js';import Navbar from'./components/NavComponents/Navbar.js';import PublishRoomPage from'./Pages/PublishRoomPage.js';import LoginForm from'./components/LoginForm.js';import LoadingBar from'react-top-loading-bar';import PreviewRoomPage from'./Pages/PreviewRoomPage.js';import RegisterHostPage from'./Pages/RegisterHostPage.js';import {axAuth}from'./API.js';import OwnerListProperty from'./Pages/OwnerListProperty.js';// theme.components.Button.baseStyle.borderRadius = "0";
const myTheme = extendTheme({
    config: {
        initialColorMode: 'dark',
    },
    components: {
        Button: {
            defaultProps: {},
        },
    },
});
const queryClient = new QueryClient({
    defaultOptions: {
        queries: {},
    },
});
const App = () => {
    const loadingRef = React.useRef(null);
    // loading bar will appear when a request is sended
    // and disappear when get a response
    // REMINDER: this is a fastest way to indicate top loading bar,
    // but not in a very elegant way, should put it in a context and update manually in component
    React.useEffect(() => {
        loadingRef.current.complete();
        axAuth.interceptors.request.use((config) => {
            loadingRef.current.staticStart();
            return config;
        }, (e) => {
            loadingRef.current.complete();
            return Promise.reject(e);
        });
        axAuth.interceptors.response.use((config) => {
            loadingRef.current.complete();
            return config;
        }, (e) => {
            loadingRef.current.complete();
            return Promise.reject(e);
        });
    }, []);
    return (React.createElement(HashRouter, { basename: "/" },
        React.createElement(ChakraProvider, { theme: myTheme },
            React.createElement(QueryClientProvider, { client: queryClient },
                React.createElement(Box, { d: "flex", flexDir: "column", minH: "100vh" },
                    React.createElement(AuthProvider, null,
                        React.createElement(Box, { flex: "1" },
                            React.createElement(LoadingBar, { color: "#f11946", ref: loadingRef }),
                            React.createElement(Switch, null,
                                React.createElement(Route, { exact: true, path: "/" },
                                    React.createElement(HomePage, null)),
                                React.createElement(Route, { component: LoginPage, exact: true, path: "/login", render: ({ location }) => (React.createElement(Redirect, { to: { pathname: '/login', state: { from: location } } })) }),
                                React.createElement(Box, { mx: { base: '10px', md: '50px', lg: '100px' }, mt: "5" },
                                    React.createElement(Navbar, null),
                                    React.createElement(Switch, null,
                                        React.createElement(Route, { exact: true, path: "/rooms/:slug", component: SingleRoom }),
                                        React.createElement(Route, { exact: true, path: "/rooms", component: RoomsPage }),
                                        React.createElement(Route, { exact: true, path: "/room/preview", component: PreviewRoomPage }),
                                        React.createElement(AuthRoute, { exact: true, path: "/profile", component: ProfilePage }),
                                        React.createElement(RoleRoute, { roles: ['Owner'], path: "/host/publish", component: PublishRoomPage }),
                                        React.createElement(AuthRoute, { exact: true, path: "/user/register-host", component: RegisterHostPage }),
                                        React.createElement(RoleRoute, { roles: ['Admin'], exact: true, path: "/admin" }),
                                        React.createElement(RoleRoute, { roles: ['Owner'], path: "/host/properties" },
                                            React.createElement(OwnerListProperty, null)),
                                        React.createElement(Route, { component: ErrorPage })))))),
                    React.createElement(Divider, { mt: "10" }),
                    React.createElement(Footer, { mx: { base: '10px', md: '50px', lg: '100px' } }))))));
};
const LoginPage = () => {
    const location = useLocation();
    const auth = React.useContext(AuthContext);
    let { from } = location.state || { from: { pathname: '/' } };
    if (auth.user)
        return React.createElement(Redirect, { to: from });
    return (React.createElement(Box, { mx: "20%", mt: "10", flex: "0" },
        React.createElement(Navbar, null),
        React.createElement(LoginForm, { isRegistering: false })));
};
const AuthRoute = (_a) => {
    var { children } = _a, rest = __rest(_a, ["children"]);
    let auth = React.useContext(AuthContext);
    if (auth.user)
        return React.createElement(Route, Object.assign({}, rest), children);
    else
        return (React.createElement(Route, Object.assign({}, rest),
            React.createElement(Redirect, { to: Object.assign({ pathname: '/login', state: {
                        from: rest.path,
                    } }, rest.location) })));
};
const RoleRoute = (props) => {
    var _a;
    const { roles, children } = props, rest = __rest(props, ["roles", "children"]);
    const auth = React.useContext(AuthContext);
    if (!auth.user)
        return (React.createElement(Route, Object.assign({}, rest),
            React.createElement(Redirect, { to: Object.assign({ pathname: '/login', state: {
                        from: rest.path,
                    } }, rest.location) })));
    const ifContainsAll = (haystack, needles) => {
        if (!haystack)
            return false;
        if (!needles)
            return true;
        for (const n of needles) {
            if (!haystack.includes(n))
                return false;
        }
        return true;
    };
    if (ifContainsAll((_a = auth.user) === null || _a === void 0 ? void 0 : _a.roles, roles))
        return React.createElement(Route, Object.assign({}, rest), children);
    else
        return (React.createElement(Route, Object.assign({}, rest),
            React.createElement(Redirect, { to: {
                    pathname: '/error',
                    state: {
                        message: 'You are not authorized',
                    },
                } })));
};export{App};//# sourceMappingURL=App.js.map
