import {chakra,FormControl,FormLabel,Input,FormErrorMessage,Collapse,Checkbox,Button}from'@chakra-ui/react';import React__default from'react';import {FaArrowRight}from'react-icons/fa';import {useHistory}from'react-router';import {AuthContext}from'../Contexts/AuthContext.js';function validateEmail(email) {
    if (!email)
        return false;
    const re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return re.test(email);
}
const LoginForm = ({ initRef, fromUrl, isRegistering }) => {
    const history = useHistory();
    const [loginForm, setLoginForm] = React__default.useState({
        remember: false,
        isRegistering: isRegistering
    });
    const [emailError, setEmailError] = React__default.useState(false);
    const [passwordError, setPasswordError] = React__default.useState(false);
    const [confirmPasswordError, setConfirmPasswordError] = React__default.useState(false);
    const validateForm = (email, password) => {
        if (validateEmail(email)) {
            setEmailError(false);
        }
        else
            setEmailError(true);
        if (password === "") {
            setPasswordError(true);
        }
        else
            setPasswordError(false);
    };
    React__default.useEffect(() => {
        validateForm(loginForm.email, loginForm.password);
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [loginForm.email, loginForm.password]);
    React__default.useEffect(() => {
        if (loginForm.isRegistering && loginForm.confirmedPassword === loginForm.password) {
            console.log(loginForm.password);
            console.log(loginForm.confirmedPassword);
            setConfirmPasswordError(false);
            console.log(confirmPasswordError);
        }
        else
            setConfirmPasswordError(true);
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [loginForm.confirmedPassword, loginForm.isRegistering, loginForm.password]);
    const authContext = React__default.useContext(AuthContext);
    const handleLogin = () => {
        authContext.loginAsync(loginForm);
        if (fromUrl)
            history.replace(fromUrl);
    };
    const handleRegister = () => {
        authContext.registerAsync({ email: loginForm.email, password: loginForm.password, confirmPassword: loginForm.confirmedPassword });
        if (fromUrl)
            history.replace(fromUrl);
    };
    const toggleMode = () => {
        setLoginForm((s) => (Object.assign(Object.assign({}, s), { isRegistering: !s.isRegistering })));
    };
    return (React__default.createElement(chakra.form, { d: "flex", flexDir: "column" },
        React__default.createElement(FormControl, { isInvalid: emailError },
            React__default.createElement(FormLabel, { htmlFor: "email" }, "Email"),
            React__default.createElement(Input, { placeholder: "Enter your email", id: "email", isInvalid: emailError, ref: initRef, variant: "filled", size: "lg", type: "email", value: loginForm.email, isRequired: true, onChange: (e) => setLoginForm(s => (Object.assign(Object.assign({}, s), { email: e.target.value.trim() }))) }),
            React__default.createElement(FormErrorMessage, null, "Email not correct")),
        React__default.createElement(FormControl, { isInvalid: passwordError },
            React__default.createElement(FormLabel, { htmlFor: "password", my: "2" }, "Password"),
            React__default.createElement(Input, { placeholder: "Enter your password", id: "password", isInvalid: passwordError, variant: "filled", size: "lg", type: "password", value: loginForm.password, minLength: 1, isRequired: true, onChange: (e) => setLoginForm(s => (Object.assign(Object.assign({}, s), { password: e.target.value }))) })),
        React__default.createElement(Collapse, { in: loginForm.isRegistering },
            React__default.createElement(FormControl, { isInvalid: confirmPasswordError },
                React__default.createElement(FormLabel, { htmlFor: "confirm-password", my: "2" }, "Confirm Password"),
                React__default.createElement(Input, { placeholder: "Confirm your password", id: "confirm-password", isInvalid: confirmPasswordError, variant: "filled", size: "lg", type: "password", value: loginForm.confirmedPassword, minLength: 1, isRequired: true, onChange: (e) => setLoginForm(s => (Object.assign(Object.assign({}, s), { confirmedPassword: e.target.value }))) })),
            React__default.createElement(FormErrorMessage, null, "Password does not match")),
        React__default.createElement(Checkbox, { size: "lg", checked: loginForm.remember, mt: "2", onChange: (e) => setLoginForm(s => (Object.assign(Object.assign({}, s), { remember: e.target.checked }))) }, "Remember me"),
        React__default.createElement(Button, { my: "3", w: "30%", rounded: "full", type: "submit", alignSelf: "center", title: "Login", isLoading: authContext.isLoading, isDisabled: loginForm.isRegistering ? emailError || passwordError || confirmPasswordError : emailError || passwordError, onClick: !loginForm.isRegistering ? handleLogin : handleRegister },
            React__default.createElement(FaArrowRight, null)),
        React__default.createElement(Button, { variant: "link", alignSelf: "center", textStyle: "", onClick: () => toggleMode() }, !loginForm.isRegistering ? "Register your account!" : "Or login instead!")));
};export default LoginForm;//# sourceMappingURL=LoginForm.js.map
